@@ -1,5 +1,5 @@
 from aishu import setting
-
+from aishu.datafaker.profession.entity import ip
 def sql(key):
     """
     对应数据服务的sql语句注册
@@ -71,7 +71,7 @@ def sql(key):
         'AgentJobTemplateID': {'sql': "SELECT id FROM AgentJobTemplate", 'database': 'AnyRobot'},
         'JobID': {'sql': "SELECT id FROM AgentJobInfo;", 'database': 'AnyRobot'},
         'uploadID': {'sql': "SELECT id FROM Upload;", 'database': 'AnyRobot'},
-        'uninstallHostID': {'sql':"SELECT id From AgentHost WHERE ip='10.4.15.54';",'database': 'AnyRobot'},
+        'uninstallHostID': {'sql':"SELECT id From AgentHost WHERE ip='{ip}';".format(ip=ip.date().getAentHostIp()),'database': 'AnyRobot'},
         'entitygroupId': {'sql':"SELECT id From KAIEntityGroup ;",'database': 'AnyRobot'},
         'serviceKpiId': {'sql':"SELECT id From KAIKpi ;",'database': 'AnyRobot'},
         'serviceHeathId': {'sql':"SELECT serviceId From KAIHealth ;",'database': 'AnyRobot'},
@@ -93,7 +93,9 @@ def sql(key):
         'ReprotIdDisable': {'sql': "SELECT report_id From report WHERE is_share_allowed = 0;", 'database': 'AnyRobot'},
         'ReprotName': {'sql': "SELECT `name` From report ;", 'database': 'AnyRobot'},
         'ReprotType': {'sql': "SELECT `type` From report ;", 'database': 'AnyRobot'},
-        'CorrelationSearchesId': {'sql': "SELECT `id` From correlate_search ;", 'database': 'AnyRobot'}
+        'CorrelationSearchesId': {'sql': "SELECT `id` From correlate_search ;", 'database': 'AnyRobot'},
+        'DataTableId': {'sql': 'select id from Kibana where title="文件采集详情";', 'database': 'AnyRobot'},
+
     }
 
     if switcher.get(key) is not None:
